@@ -185,6 +185,7 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         logy: bool = False,
         bin_width_in_ylabel: bool = False,
         underoverflow: bool = False,
+        grid: bool = False,
         **kwargs,
     ) -> None:
         """histogram plot properties
@@ -216,6 +217,8 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             Specify if the bin width should be added to the ylabel, by default False
         underoverflow : bool, optional
             Option to include under- and overflow values in outermost bins.
+        grid : bool, optional
+            Set the grid for the plots.
         **kwargs : kwargs
             Keyword arguments from `puma.PlotObject`
 
@@ -226,7 +229,7 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         """
         # TODO: use union operator `|` for multiple types of `bins` in python 3.10
 
-        super().__init__(**kwargs)
+        super().__init__(grid=grid, **kwargs)
         self.logy = logy
         self.bins = bins
         self.bins_range = bins_range
@@ -237,11 +240,11 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         self.plot_objects = {}
         self.add_order = []
         self.ratios_objects = {}
-        self.ratio_axes = {}
         self.reference_object = None
+
         if self.n_ratio_panels > 1:
             raise ValueError("Not more than one ratio panel supported.")
-        self.initialise_figure(sub_plot_index=6)
+        self.initialise_figure()
 
     def add(self, histogram: object, key: str = None, reference: bool = False):
         """Adding histogram object to figure.
@@ -550,7 +553,7 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             ratio_unc_band_high = np.nan_to_num(ratio + ratio_unc, nan=0, posinf=0)
 
             # Plot the ratio values with the step function
-            self.axis_ratio_1.step(
+            self.ratio_axes[0].step(
                 x=elem.bin_edges,
                 y=ratio,
                 color=elem.colour,
@@ -560,7 +563,7 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
 
             # Plot the ratio uncertainty
             if self.draw_errors:
-                self.axis_ratio_1.fill_between(
+                self.ratio_axes[0].fill_between(
                     x=elem.bin_edges,
                     y1=ratio_unc_band_low,
                     y2=ratio_unc_band_high,
@@ -621,8 +624,8 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
 
         if self.n_ratio_panels > 0:
             self.set_ylabel(
-                self.axis_ratio_1,
-                self.ylabel_ratio_1,
+                self.ratio_axes[0],
+                self.ylabel_ratio[0],
                 align_right=False,
                 labelpad=labelpad,
             )
@@ -635,8 +638,5 @@ class HistogramPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         self.make_legend(plt_handles, ax_mpl=legend_axis)
         self.set_title()
 
-        if not self.atlas_tag_outside:
-            self.fig.tight_layout()
-
         if self.apply_atlas_style:
             self.atlasify()
