@@ -46,7 +46,6 @@ class Line2D(PlotLineObject):  # pylint: disable=too-few-public-methods
 
         # Check input dtype
         if isinstance(x_values, (np.ndarray, list, int, float, pd.Series)):
-
             if type(x_values) != type(y_values):  # pylint: disable=C0123
                 raise ValueError(
                     "Invalid types of input given! Both must be one of the following: "
@@ -100,6 +99,7 @@ class Line2DPlot(PlotBase):
     def __init__(
         self,
         logy: bool = False,
+        grid: bool = True,
         **kwargs,
     ) -> None:
         """Plot properties
@@ -108,11 +108,13 @@ class Line2DPlot(PlotBase):
         ----------
         logy : bool, optional
             Decide, if the y-axis of the plot will be in log, by default False
+        grid : bool, optional
+            Set the grid for the plots.
         **kwargs : kwargs
             Keyword arguments from `puma.PlotObject`
         """
 
-        super().__init__(**kwargs)
+        super().__init__(grid=grid, **kwargs)
 
         # Set inputs as attributes
         self.logy = logy
@@ -121,7 +123,7 @@ class Line2DPlot(PlotBase):
         self.plot_objects = {}
         self.add_order = []
 
-        self.initialise_figure(sub_plot_index=6)
+        self.initialise_figure()
 
     def add(
         self,
@@ -259,13 +261,6 @@ class Line2DPlot(PlotBase):
         self.set_tick_params()
         self.set_ylabel(self.axis_top)
 
-        if not self.atlas_tag_outside:
-            self.fig.tight_layout()
-
-        # Set grid if grid is true
-        if self.grid:
-            self.axis_top.grid()
-
         # Apply atlas style if defined
         if self.apply_atlas_style:
             self.atlasify()
