@@ -6,7 +6,7 @@ from scipy.interpolate import pchip
 
 from puma.metrics import rej_err
 from puma.plot_base import PlotBase, PlotLineObject
-from puma.utils import get_good_colours, logger
+from puma.utils import get_good_colours, get_good_linestyles, global_config, logger
 
 
 class Roc(PlotLineObject):
@@ -187,28 +187,28 @@ class Roc(PlotLineObject):
 class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
     """ROC plot class"""
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, grid: bool = True, **kwargs) -> None:
         """ROC plot properties
 
         Parameters
         ----------
+        grid : bool, optional
+            Set the grid for the plots.
         **kwargs : kwargs
             Keyword arguments from `puma.PlotObject`
         """
-        super().__init__(**kwargs)
+        super().__init__(grid=grid, **kwargs)
         self.test = ""
         self.rocs = {}
         self.roc_ratios = {}
-        self.ratio_axes = {}
+        self.rej_axes = {}
         self.rej_class_ls = {}
         self.label_colours = {}
         self.leg_rej_labels = {}
         self.reference_roc = None
         self.initialise_figure()
         self.eff_min, self.eff_max = (1, 0)
-        # setting default linestyles if no linestyles provided
-        # solid line and densed dotted dashed
-        self.default_linestyles = ["-", (0, (3, 1, 1, 1))]
+        self.default_linestyles = get_good_linestyles()
         self.legend_flavs = None
         self.leg_rej_loc = "lower left"
 
@@ -315,20 +315,8 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             )
             self.reference_roc[rej_class] = key
 
-    def set_leg_rej_labels(self, rej_class: str, label: str):
-        """Set legend label for rejection class
-
-        Parameters
-        ----------
-        rej_class : str
-            Rejection class
-        label : str
-            Label added in legend
-        """
-        self.leg_rej_labels[rej_class] = label
-
-    def set_ratio_class(self, ratio_panel: int, rej_class: str, label: str):
-        """Associate the rejection class to a ratio panel
+    def set_ratio_class(self, ratio_panel: int, rej_class: str):
+        """Associate the rejection class to a ratio panel adn set the legend label
 
         Parameters
         ----------
@@ -336,20 +324,20 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             Ratio panel either 1 or 2
         rej_class : str
             Rejeciton class associated to that panel
-        label : str
-            y-axis label of the ratio panel
 
         Raises
         ------
         ValueError
             if requested ratio panels and given ratio_panel do not match.
         """
-        if self.n_ratio_panels < ratio_panel and ratio_panel not in [1, 2]:
+        if self.n_ratio_panels < ratio_panel:
             raise ValueError(
                 "Requested ratio panels and given ratio_panel do not match."
             )
-        self.ratio_axes[ratio_panel] = rej_class
-        self.set_ratio_label(ratio_panel, label)
+        self.rej_axes[rej_class] = self.ratio_axes[ratio_panel - 1]
+        label = global_config["flavour_categories"][rej_class]["legend_label"]
+        self.set_ratio_label(ratio_panel, f"{label} ratio")
+        self.leg_rej_labels[rej_class] = label
 
     def add_ratios(self):
         """Calculating ratios.
@@ -366,20 +354,13 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
                 f"{len(self.reference_roc)} reference rocs defined but requested "
                 f"{self.n_ratio_panels} ratio panels."
             )
-        if len(self.ratio_axes) != self.n_ratio_panels:
+        if len(self.rej_axes) != self.n_ratio_panels:
             raise ValueError(
                 "Ratio classes not set, set them first with `set_ratio_class`."
             )
-        self.plot_ratios(axis=self.axis_ratio_1, rej_class=self.ratio_axes[1])
 
-        if self.grid:
-            self.axis_ratio_1.grid()
-
-        if self.n_ratio_panels == 2:
-            self.plot_ratios(axis=self.axis_ratio_2, rej_class=self.ratio_axes[2])
-
-            if self.grid:
-                self.axis_ratio_2.grid()
+        for rej_class, axis in self.rej_axes.items():
+            self.plot_ratios(axis=axis, rej_class=rej_class)
 
     def get_xlim_auto(self):
         """Returns min and max efficiency values
@@ -466,46 +447,35 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             If not 2 ratios requested
         """
 
-        if self.n_ratio_panels != 2:
+        if self.n_ratio_panels < 2:
             raise ValueError("For a split legend you need 2 ratio panels.")
 
         if self.leg_rej_loc == "ratio_legend":
-            legend_line = mpl.lines.Line2D(
-                [],
-                [],
-                color="k",
-                label=self.leg_rej_labels[self.ratio_axes[1]],
-                linestyle=self.rej_class_ls[self.ratio_axes[1]],
-            )
-            self.axis_ratio_1.legend(
-                handles=[legend_line],
-                labels=[legend_line.get_label()],
-                loc="upper right",
-                fontsize=self.leg_fontsize,
-            )
-            legend_line = mpl.lines.Line2D(
-                [],
-                [],
-                color="k",
-                label=self.leg_rej_labels[self.ratio_axes[2]],
-                linestyle=self.rej_class_ls[self.ratio_axes[2]],
-            )
-            self.axis_ratio_2.legend(
-                handles=[legend_line],
-                labels=[legend_line.get_label()],
-                loc="upper right",
-                fontsize=self.leg_fontsize,
-            )
+            for rej_class, axis in self.rej_axes.items():
+                legend_line = mpl.lines.Line2D(
+                    [],
+                    [],
+                    color="k",
+                    label=self.leg_rej_labels[rej_class],
+                    linestyle=self.rej_class_ls[rej_class],
+                )
+                axis.legend(
+                    handles=[legend_line],
+                    labels=[legend_line.get_label()],
+                    loc="upper right",
+                    fontsize=self.leg_fontsize,
+                )
+
         else:
             line_list_rej = []
-            for elem in [self.ratio_axes[1], self.ratio_axes[2]]:
+            for rej_class in self.rej_axes:
                 line_list_rej.append(
                     mpl.lines.Line2D(
                         [],
                         [],
                         color="k",
-                        label=self.leg_rej_labels[elem],
-                        linestyle=self.rej_class_ls[elem],
+                        label=self.leg_rej_labels[rej_class],
+                        linestyle=self.rej_class_ls[rej_class],
                     )
                 )
 
@@ -564,20 +534,11 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         self.set_y_lim()
         self.set_xlabel()
         self.set_ylabel(self.axis_top)
-        if self.grid:
-            self.axis_top.grid()
 
-        if self.n_ratio_panels > 0:
+        for i, axis in enumerate(self.rej_axes.values()):
             self.set_ylabel(
-                self.axis_ratio_1,
-                self.ylabel_ratio_1,
-                align_right=False,
-                labelpad=labelpad,
-            )
-        if self.n_ratio_panels == 2:
-            self.set_ylabel(
-                self.axis_ratio_2,
-                self.ylabel_ratio_2,
+                axis,
+                self.ylabel_ratio[i],
                 align_right=False,
                 labelpad=labelpad,
             )
@@ -586,8 +547,8 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             self.make_legend(plt_handles, ax_mpl=self.axis_top)
         else:
             if not self.leg_rej_labels:
-                self.leg_rej_labels[self.ratio_axes[1]] = self.ratio_axes[1]
-                self.leg_rej_labels[self.ratio_axes[2]] = self.ratio_axes[2]
+                for rej_class in self.rej_axes:
+                    self.leg_rej_labels[rej_class] = rej_class
 
             self.make_split_legend(handles=plt_handles)
 
@@ -599,9 +560,6 @@ class RocPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             if self.legend_flavs is not None:
                 self.legend_flavs.set_frame_on(False)
 
-        if not self.atlas_tag_outside:
-            self.tight_layout()
-
     def plot_roc(self, **kwargs) -> mpl.lines.Line2D:
         """Plotting roc curves
 
