@@ -433,7 +433,7 @@ class VarVsEff(PlotLineObject):  # pylint: disable=too-many-instance-attributes
 class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
     """var_vs_eff plot class"""
 
-    def __init__(self, mode, **kwargs) -> None:
+    def __init__(self, mode, grid: bool = False, **kwargs) -> None:
         """var_vs_eff plot properties
 
         Parameters
@@ -441,6 +441,8 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         mode : str
             Defines which quantity is plotted, the following options ar available:
             "sig_eff", "bkg_eff", "sig_rej" or "bkg_rej"
+        grid : bool, optional
+            Set the grid for the plots.
         **kwargs : kwargs
             Keyword arguments from `puma.PlotObject`
 
@@ -449,7 +451,7 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         ValueError
             If incompatible mode given or more than 1 ratio panel requested
         """
-        super().__init__(**kwargs)
+        super().__init__(grid=grid, **kwargs)
         mode_options = ["sig_eff", "bkg_eff", "sig_rej", "bkg_rej"]
         if mode not in mode_options:
             raise ValueError(
@@ -460,14 +462,13 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
         self.plot_objects = {}
         self.add_order = []
         self.ratios_objects = {}
-        self.ratio_axes = {}
         self.reference_object = None
         self.bin_edge_min = np.inf
         self.bin_edge_max = -np.inf
         self.inverse_cut = False
         if self.n_ratio_panels > 1:
             raise ValueError("Not more than one ratio panel supported.")
-        self.initialise_figure(sub_plot_index=6)
+        self.initialise_figure()
 
     def add(self, curve: object, key: str = None, reference: bool = False):
         """Adding var_vs_eff object to figure.
@@ -609,7 +610,7 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
                 mode=self.mode,
                 inverse_cut=self.inverse_cut,
             )
-            error_bar = self.axis_ratio_1.errorbar(
+            error_bar = self.ratio_axes[0].errorbar(
                 x_bin_centres,
                 ratio,
                 xerr=bin_widths,
@@ -626,7 +627,7 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
             down_variation = np.concatenate((down_variation[:1], down_variation[:]))
             up_variation = np.concatenate((up_variation[:1], up_variation[:]))
 
-            self.axis_ratio_1.fill_between(
+            self.ratio_axes[0].fill_between(
                 elem.bin_edges,
                 down_variation,
                 up_variation,
@@ -637,11 +638,6 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
                 edgecolor="none",
             )
 
-    def set_grid(self):
-        """Set gtid lines."""
-        self.axis_top.grid()
-        self.axis_ratio_1.grid()
-
     def set_inverse_cut(self, inverse_cut=True):
         """Invert the discriminant cut, which will yield the efficiency or rejection
         of the jets not passing the working point.
@@ -698,14 +694,12 @@ class VarVsEffPlot(PlotBase):  # pylint: disable=too-many-instance-attributes
 
         if self.n_ratio_panels > 0:
             self.set_ylabel(
-                self.axis_ratio_1,
-                self.ylabel_ratio_1,
+                self.ratio_axes[0],
+                self.ylabel_ratio[0],
                 align_right=False,
                 labelpad=labelpad,
             )
         self.make_legend(plt_handles, ax_mpl=self.axis_top)
-        if not self.atlas_tag_outside:
-            self.tight_layout()
         self.plotting_done = True
         if self.apply_atlas_style is True:
             self.atlasify(use_tag=self.use_atlas_tag)
